@@ -4,7 +4,7 @@ import csv
 
 from tensorflow.python.keras.models import load_model
 
-from graphmanagerlib.DataForGCN import DataTransformer
+from graphmanagerlib.Data_for_gcn import get_data
 from graphmanagerlib.Node import Node
 
 import stellargraph as sg
@@ -20,13 +20,12 @@ from tensorflow.python.keras.callbacks import EarlyStopping
 
 
 class GraphManager :
-    def __init__(self, documents, tagsPath):
+    def __init__(self, documents, tagsPath,save_dataset_fd):
         tags = []
         with open(tagsPath, newline='') as inputfile:
             for row in csv.reader(inputfile):
                 tags.append(row[0])
-        self.nodes, self.edges, self.tags = DataTransformer().get_data(documents=documents,
-                                                                       tags=tags)
+        self.nodes, self.edges, self.tags = get_data(documents=documents,save_dataset_fd=save_dataset_fd)
 
     def TrainModel(self):
         nodes = self.nodes
